{flake, ...}: let
  inherit (flake.config.people) user0;
  inherit (flake.config.people.user.${user0}) aliases;
  inherit (flake.config.system.device) nas server;
  inherit (flake.config.service) instance;
  gitlabTags = ["git" "gitlab"];
  youtubeTags = ["youtube" "you" "tube" "yt"];
  jellyfinTags = ["jelly" "video" "streaming" "movies" "shows" "music"];
  ollamaTags = [instance.ollama.name "chat" "ai"];
  owncastTags = [instance.owncast.name "own" "cast" "stream"];
  syncthingTags = [instance.syncthing.name "sync" "thing" instance.synology.name];
in {
  programs.firefox.profiles = {
    ${user0} = {
      bookmarks = [
        {
          name = "Academic";
          toolbar = false;
          bookmarks = [
            {
              name = "PubMed";
              url = "https://pubmed.ncbi.nlm.nih.gov/";
              tags = ["pub" "pubmed" "science" "research" "academic"];
              keyword = "Pub";
            }
            {
              name = "Sci-Hub";
              url = "https://sci-hub.ee/";
              tags = ["sci" "sci-hub" "scihub" "science" "research" "academic" "torrent"];
              keyword = "Sci";
            }
            {
              name = "Stanford Encyclopedia of Philosophy";
              url = "https://plato.stanford.edu/";
              tags = ["standford" "encyclopedia" "philosophy" "phil"];
              keyword = "Phil";
            }
            {
              name = "Zotero Bibliography";
              url = "https://zbib.org/";
              tags = ["votero" "bibliography" "bib" "zbib"];
              keyword = "Bib";
            }
          ];
        }
        {
          name = "Development";
          toolbar = false;
          bookmarks = [
            {
              name = "Discord (Development Portal)";
              url = "https://discord.com/developers/applications";
              tags = ["discord" "development" "portal" "bot"];
              keyword = "Discord";
            }
            {
              name = "GitHub";
              url = "https://github.com/BRBWaffles";
              tags = ["git" "github" "brbwaffles"];
              keyword = "GitHub";
            }
            {
              name = "GitLab (Appoota)";
              url = "https://gitlab.com/Appoota/dotfiles";
              tags =
                ["appoota"]
                ++ gitlabTags;
              keyword = "GitLab";
            }
            {
              name = "GitLab (Fallaryn)";
              url = "https://gitlab.com/fallaryn/dotfiles";
              tags =
                ["fallaryn"]
                ++ gitlabTags;
              keyword = "GitLab";
            }
            {
              name = "GitLab (Isaac)";
              url = "https://gitlab.com/askyourself/dotfiles";
              tags =
                ["isaac" "askyourself"]
                ++ gitlabTags;
              keyword = "GitLab";
            }
            {
              name = "GitLab (Nick)";
              url = "https://gitlab.com/BRBWaffles/dotfiles";
              tags =
                ["brbwaffles"]
                ++ gitlabTags;
              keyword = "GitLab";
            }
            {
              name = "Hackage";
              url = "https://hackage.haskell.org/";
              tags = ["hackage" "hack" "haskell"];
              keyword = "Hack";
            }
          ];
        }
        {
          name = "Gaming";
          toolbar = false;
          bookmarks = [
            {
              name = "Battle.net";
              url = "https://us.shop.battle.net";
              tags = ["battle.net" "battle" "net"];
              keyword = "Battle";
            }
            {
              name = "Chess.com";
              url = "https://www.chess.com/home";
              tags = ["chess"];
              keyword = "Chess";
            }
            {
              name = "Lichess";
              url = "https://lichess.org/";
              tags = ["lichess" "chess"];
              keyword = "Li";
            }
            {
              name = "ProtonDB";
              url = "https://www.protondb.com/";
              tags = ["steam" "db"];
              keyword = "DB";
            }
            {
              name = "SteamDB";
              url = "https://steamdb.info/";
              tags = ["steamdb" "steam" "db"];
              keyword = "SteamDB";
            }
          ];
        }
        {
          name = "Finances";
          toolbar = false;
          bookmarks = [
            {
              name = "Adsense";
              url = "https://www.google.com/adsense/new/u/0/pub-4524791551954022/payments";
              tags = ["google" "adsense" "ads" "money"];
              keyword = "Adsense";
            }
            {
              name = "Canada Revenue Agency";
              url = "https://apps4.ams-sga.cra-arc.gc.ca/gol-ged/awsc/amss/browser/check?program=mima&target=login&lang=en&idp=cms";
              tags = ["cra" "canada" "money"];
              keyword = "CRA";
            }
            {
              name = "Credit Karma";
              url = "https://www.creditkarma.ca/";
              tags = ["credit" "karma" "bank" "banking"];
              keyword = "Credit";
            }
            {
              name = "Kijiji";
              url = "https://www.kijiji.ca";
              tags = ["kijiji" "kij" "ki"];
              keyword = "Kij";
            }
            {
              name = "LiberaPay";
              url = "https://liberapay.com/TheNutrivore/";
              tags = ["libera" "liberapay" "donations" "bank" "banking" "money" "nutrivore"];
              keyword = "Libera";
            }
            {
              name = "Patreon";
              url = "https://www.patreon.com/thenutrivore";
              tags = ["patreon" "donations" "bank" "banking" "money" "nutrivore"];
              keyword = "Patreon";
            }
            {
              name = "PayPal";
              url = "https://www.paypal.com/myaccount/summary?intl=0";
              tags = ["paypal" "bank" "banking" "money"];
              keyword = "PayPal";
            }
            {
              name = "Shopify";
              url = "https://the-nutrivore.myshopify.com/admin";
              tags = ["shopify" "business" "shop" "bank" "banking" "money"];
              keyword = "Shopify";
            }
            {
              name = "Simplii";
              url = "https://online.simplii.com/ebm-resources/public/client/web/index.html#/signon";
              tags = ["simplii" "bank" "banking" "money"];
              keyword = "Simplii";
            }
            {
              name = "Stripe";
              url = "https://dashboard.stripe.com/settings/user";
              tags = ["stripe" "bank" "banking" "money"];
              keyword = "Stripe";
            }
            {
              name = "Telus (Security)";
              url = "https://smarthome-security.telus.com/web/system/home";
              tags = ["telus" "security"];
              keyword = "ADT";
            }
            {
              name = "Wealthsimple";
              url = "https://my.wealthsimple.com/app/tax-onboarding/2021";
              tags = ["wealth" "simple" "bank" "banking" "crypto"];
              keyword = "Wealth";
            }
            {
              name = "Wix";
              url = "https://manage.wix.com/dashboard/413fd74d-8a8f-4c77-bd91-9ea560ffe906/home";
              tags = ["wix" "website" "business" "bills" "nutrivore"];
              keyword = "Wix";
            }
          ];
        }
        {
          name = "Self Hosted";
          toolbar = false;
          bookmarks = [
            {
              name = instance.forgejo.label;
              url = "https://${instance.forgejo.subdomain}.${instance.web.domains.url0}";
              tags = [instance.forgejo.name "forge" "git"];
              keyword = instance.forgejo.label;
            }
            {
              name = "${instance.jellyfin.label} (Internet)";
              url = "https://${instance.jellyfin.name}.${instance.web.domains.url0}";
              tags = jellyfinTags;
              keyword = instance.jellyfin.label;
            }
            {
              name = "${instance.jellyfin.label} (Local)";
              url = "http://${server.ip.address0}:${toString instance.jellyfin.ports.port1}";
              tags = jellyfinTags;
              keyword = instance.jellyfin.label;
            }
            {
              name = instance.mastodon.label;
              url = "https://${instance.web.domains.url1}";
              tags = [instance.mastodon.name "mast" "md"];
              keyword = instance.mastodon.label;
            }
            {
              name = "Namecheap";
              url = "https://www.namecheap.com/";
              tags = ["namecheap" "name" "cheap" "dns"];
              keyword = "Name";
            }
            {
              name = instance.nextcloud.label;
              url = "https://${instance.nextcloud.subdomain}.${instance.web.domains.url1}";
              tags = [instance.nextcloud.name "next" "cloud" "calendar"];
              keyword = instance.nextcloud.label;
            }
            {
              name = aliases.name2;
              url = instance.web.domains.url2;
              tags = [aliases.name3 "blog"];
              keyword = aliases.name2;
            }
            {
              name = "${instance.ollama.label} (Server)";
              url = "https://${instance.ollama.subdomain}.${instance.web.domains.url1}";
              tags = ollamaTags;
              keyword = instance.ollama.label;
            }
            {
              name = "${instance.ollama.label} (Desktop)";
              url = "http://localhost:${toString instance.ollama.ports.port0}";
              tags = ollamaTags;
              keyword = instance.ollama.label;
            }
            {
              name = "${instance.owncast.label} (Admin)";
              url = "http://${server.ip.address0}:${toString instance.owncast.ports.port0}/admin";
              tags = owncastTags;
              keyword = instance.owncast.label;
            }
            {
              name = "${instance.owncast.label} (Server)";
              url = "http://${instance.owncast.subdomain}.${instance.web.domains.url1}";
              tags = owncastTags;
              keyword = instance.owncast.label;
            }
            {
              name = instance.peertube.label;
              url = "https://${instance.peertube.subdomain}.${instance.web.domains.url1}";
              tags = [instance.peertube.name "peer" "tube" "nutrivore"];
              keyword = instance.peertube.label;
            }
            {
              name = "Router";
              url = "http://${instance.web.localhost.address2}";
              tags = ["router" "asus"];
              keyword = "Router";
            }
            {
              name = "${instance.syncthing.label} (${instance.synology.label})";
              url = "http://${nas.ip.address0}:${toString instance.syncthing.ports.port0}";
              tags =
                ["synology"]
                ++ syncthingTags;
              keyword = instance.syncthing.label;
            }
            {
              name = "${instance.syncthing.label} (Desktop)";
              url = "http://localhost:${toString instance.syncthing.ports.port0}";
              tags =
                ["desktop"]
                ++ syncthingTags;
              keyword = instance.syncthing.label;
            }
            {
              name = instance.synology.label;
              url = "https://${nas.ip.address0}:${toString instance.synology.ports.port0}";
              tags = [instance.synology.name "dsm" "cloud"];
              keyword = instance.synology.label;
            }
            {
              name = instance.vaultwarden.label;
              url = "https://${instance.vaultwarden.subdomain}.${instance.web.domains.url0}";
              tags = [instance.vaultwarden.name "bitwarden" "vault" "bit" "warden"];
              keyword = instance.vaultwarden.label;
            }
            {
              name = instance.wiki.label;
              url = "https://${instance.wiki.subdomain}.${instance.web.domains.url1}";
              tags = [instance.wiki.name "vault"];
              keyword = instance.wiki.label;
            }
          ];
        }
        {
          name = "Shopping";
          toolbar = false;
          bookmarks = [
            {
              name = "Amazon";
              url = "https://www.amazon.ca/";
              tags = ["amazon" "shopping" "supply"];
              keyword = "Amazon";
            }
            {
              name = "Door Dash";
              url = "https://www.doordash.com/";
              tags = ["doordash" "door" "dash" "food"];
              keyword = "Amazon";
            }
            {
              name = "FTY Supplies";
              url = "https://fytsupplies.ca/";
              tags = ["tattoo tat" "fyt" "shopping" "supply"];
              keyword = "FYT";
            }
            {
              name = "Skip the Dishes";
              url = "https://www.skipthedishes.com/";
              tags = ["skip" "dishes" "food"];
              keyword = "Skip";
            }
            {
              name = "Uber Eats";
              url = "https://www.ubereats.com/";
              tags = ["uber" "eats" "food"];
              keyword = "Uber";
            }
            {
              name = "TatSoul";
              url = "https://www.tatsoul.com/";
              tags = ["tattoo" "tat" "tatsoul" "shopping" "supply"];
              keyword = "TatSoul";
            }
          ];
        }
        {
          name = "Social Media";
          toolbar = false;
          bookmarks = [
            {
              name = "Disboard";
              url = "https://disboard.org";
              tags = ["disboard" "discord" "dis" "ds" "social"];
              keyword = "Disboard";
            }
            {
              name = "Discord (Web Client)";
              url = "https://discord.com/channels/@me";
              tags = ["discord" "dis" "ds" "social"];
              keyword = "Discord";
            }
            {
              name = "Gmail";
              url = "https://mail.google.com/mail/u/0/#inbox";
              tags = ["gmail" "google" "mail" "gm" "email"];
              keyword = "Gmail";
            }
            {
              name = "Lemmy";
              url = "https://lemmy.world/";
              tags = ["lemmy" "social"];
              keyword = "Lem";
            }
            {
              name = "OnlyFans";
              url = "https://onlyfans.com/";
              tags = ["onlyfans" "only" "fans"];
              keyword = "Only";
            }
            {
              name = "Pixelfed";
              url = "https://pixelfed.social/i/web/profile/651714972141461392";
              tags = ["pixelfed" "pixel" "pi"];
              keyword = "Pix";
            }
            {
              name = "Proton Mail";
              url = "https://mail.proton.me/u/1/inbox";
              tags = ["proton" "mail" "pr" "email"];
              keyword = "Pro";
            }
            {
              name = "Proton Calendar";
              url = "https://calendar.proton.me";
              tags = ["proton" "calendar"];
              keyword = "Cal";
            }
            {
              name = "Proton VPN";
              url = "https://account.proton.me/u/0/vpn";
              tags = ["proton" "vpn"];
              keyword = "VPN";
            }
            {
              name = "Reddit";
              url = "https://www.reddit.com/";
              tags = ["reddit" "social"];
              keyword = "Reddit";
            }
            {
              name = "StreamLabs";
              url = "https://streamlabs.com/dashboard";
              tags = ["streamlabs" "stream" "labs"];
              keyword = "Stream";
            }
            {
              name = "Tinder";
              url = "https://tinder.com/app/recs";
              tags = ["tinder" "dating" "booty"];
              keyword = "Tinder";
            }
            {
              name = "YouTube";
              url = "https://www.youtube.com/";
              tags = youtubeTags;
              keyword = "You";
            }
            {
              name = "YouTube Studio";
              url = "https://studio.youtube.com/channel/UCy9yYcDx2XuVVgcWLJJDoxw";
              tags =
                ["studio"]
                ++ youtubeTags;
              keyword = "Studio";
            }
            {
              name = "X (Twitter)";
              url = "https://twitter.com/TheNutrivore";
              tags = ["twitter" "x" "social"];
              keyword = "Twitter";
            }
          ];
        }
        {
          name = "Tools";
          toolbar = false;
          bookmarks = [
            {
              name = "Uncensored AI";
              url = "https://www.aiuncensored.info/";
              tags = ["uncensored" "ai"];
              keyword = "AI";
            }
            {
              name = "Canadian Blood Services";
              url = "https://www.blood.ca/en";
              tags = ["canadian" "blood" "services" "give"];
              keyword = "Give";
            }
            {
              name = "Chmod Calculator";
              url = "https://chmod-calculator.com/";
              tags = ["chmod" "calculator"];
              keyword = "Chmod";
            }
            {
              name = "ChatGPT";
              url = "https://chatgpt.com/";
              tags = ["chat" "chatgpt" "gpt"];
              keyword = "Chat";
            }
            {
              name = "Claude AI";
              url = "https://claude.ai";
              tags = ["claude" "ai"];
              keyword = "Claude";
            }
            {
              name = "Cronometer";
              url = "https://cronometer.com/#diary";
              tags = ["cronometer" "cron" "nutrition"];
              keyword = "Cron";
            }
            {
              name = "DNS Checker";
              url = "https://dnschecker.org/";
              tags = ["dns" "checker"];
              keyword = "DNS";
            }
            {
              name = "EventBrite";
              url = "https://www.eventbrite.ca/d/canada--winnipeg/events--today/winnipeg/?page=1";
              tags = ["eventbrite" "event" "brite"];
              keyword = "Event";
            }
            {
              name = "Google Maps";
              url = "https://www.maps.google.com/";
              tags = ["maps" "google"];
              keyword = "Map";
            }
            {
              name = "ListenBrainz";
              url = "https://listenbrainz.org/user/BRBWaffles/";
              tags = ["listenbrainz" "listen" "brains"];
              keyword = "Listen";
            }
            {
              name = "Memory Express";
              url = "https://www.memoryexpress.com/";
              tags = ["memoryexpress" "memory" "mem" "express"];
              keyword = "Mem";
            }
            {
              name = "Percentage Calculator";
              url = "https://percentagecalculator.net";
              tags = ["percentage" "percent" "calculator"];
              keyword = "Percent";
            }
            {
              name = "Portchecker";
              url = "https://portchecker.co/";
              tags = ["portchecker" "port" "checker"];
              keyword = "Port";
            }
            {
              name = "Proof Tree";
              url = "https://www.umsu.de/trees/";
              tags = ["proof" "tree" "logic" "academic"];
              keyword = "Logic";
            }
            {
              name = "RhymeZone";
              url = "https://www.rhymezone.com/";
              tags = ["rhymezone" "rhyme" "zone"];
              keyword = "Rhyme";
            }
            {
              name = "Sci-Hub";
              url = "https://sci-hub.ee/";
              tags = ["sci" "sci-hub" "scihub" "science" "research" "academic" "torrent"];
              keyword = "Sci";
            }
            {
              name = "Speedtest";
              url = "https://www.speedtest.net/";
              tags = ["speedtest" "speed" "test"];
              keyword = "Speed";
            }
            {
              name = "Stanford Encyclopedia of Philosophy";
              url = "https://plato.stanford.edu/";
              tags = ["standford" "encyclopedia" "philosophy" "phil"];
              keyword = "Phil";
            }
            {
              name = "Telus (Billing)";
              url = "https://www.telus.com/my-telus/billing/summary";
              tags = ["telus" "phone" "bills" "money"];
              keyword = "Telus";
            }
            {
              name = "TinEye";
              url = "https://tineye.com/";
              tags = ["tineye" "tin" "eye"];
              keyword = "Tin";
            }
            {
              name = "Zotero Bibliography";
              url = "https://zbib.org/";
              tags = ["votero" "bibliography" "bib" "zbib"];
              keyword = "Bib";
            }
          ];
        }
        {
          name = "Tracking";
          toolbar = false;
          bookmarks = [
            {
              name = "1337";
              url = "https://1337x.to/";
              tags = ["torrent" "1337"];
              keyword = "1337";
            }
            {
              name = "Core Radio";
              url = "https://coreradio.online/";
              tags = ["core" "radio" "metal"];
              keyword = "Core";
            }
            {
              name = "Metal Tracker";
              url = "https://en.metal-tracker.com/";
              tags = ["metaltracker" "metal" "tracker"];
              keyword = "Metal";
            }
            {
              name = "Torrent Leech";
              url = "https://www.torrentleech.org/";
              tags = ["torrent" "leech"];
              keyword = "Leech";
            }
          ];
        }
      ];
    };
  };
}
